==> qt6-declarative-6.4.0beta2-1-x86_64.pkg.tar.zst: usr/include/qt6/QtLabsFolderListModel/qtlabsfolderlistmodelexports.h <==
// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QTLABSFOLDERLISTMODELEXPORTS_H
#define QTLABSFOLDERLISTMODELEXPORTS_H

#include <QtCore/qglobal.h>

#if defined(QT_SHARED) || !defined(QT_STATIC)
#  if defined(QT_BUILD_LABSFOLDERLISTMODEL_LIB)
#    define Q_LABSFOLDERLISTMODEL_EXPORT Q_DECL_EXPORT
#  else
#    define Q_LABSFOLDERLISTMODEL_EXPORT Q_DECL_IMPORT
#  endif
#else
#  define Q_LABSFOLDERLISTMODEL_EXPORT
#endif

#if !defined(QT_BUILD_LABSFOLDERLISTMODEL_LIB) || defined(QT_STATIC)
/* outside library → inline decl + defi */
#  define QT_LABSFOLDERLISTMODEL_INLINE_SINCE(major, minor) inline
#  define QT_LABSFOLDERLISTMODEL_INLINE_IMPL_SINCE(major, minor) 1
#elif defined(QT_LABSFOLDERLISTMODEL_BUILD_REMOVED_API)
/* inside library, inside removed_api.cpp → non-inline decl, defi */
#  define QT_LABSFOLDERLISTMODEL_INLINE_SINCE(major, minor) /* not inline */
#  define QT_LABSFOLDERLISTMODEL_INLINE_IMPL_SINCE(major, minor) 1
#else
/* inside library, outside removed_api.cpp → non-inline decl, no defi */
#  define QT_LABSFOLDERLISTMODEL_INLINE_SINCE(major, minor) /* not inline */
#  define QT_LABSFOLDERLISTMODEL_INLINE_IMPL_SINCE(major, minor) 0
#endif

#ifdef QT_LABSFOLDERLISTMODEL_BUILD_REMOVED_API
#  define QT_LABSFOLDERLISTMODEL_REMOVED_SINCE(major, minor) QT_DEPRECATED_SINCE(major, minor)
#else
#  define QT_LABSFOLDERLISTMODEL_REMOVED_SINCE(major, minor) 0
#endif

#endif // QTLABSFOLDERLISTMODELEXPORTS_H

==> qt6-declarative-6.5.0beta1-1-x86_64.pkg.tar.zst: usr/include/qt6/QtLabsFolderListModel/qtlabsfolderlistmodelexports.h <==
// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <QtCore/qglobal.h>

#ifndef QTLABSFOLDERLISTMODELEXPORTS_H
#define QTLABSFOLDERLISTMODELEXPORTS_H

#if defined(QT_SHARED) || !defined(QT_STATIC)
#  if defined(QT_BUILD_LABSFOLDERLISTMODEL_LIB)
#    define Q_LABSFOLDERLISTMODEL_EXPORT Q_DECL_EXPORT
#  else
#    define Q_LABSFOLDERLISTMODEL_EXPORT Q_DECL_IMPORT
#  endif
#else
#  define Q_LABSFOLDERLISTMODEL_EXPORT
#endif

#if !defined(QT_BUILD_LABSFOLDERLISTMODEL_LIB) || defined(QT_STATIC)
/* outside library → inline decl + defi */
#  define QT_LABSFOLDERLISTMODEL_INLINE_SINCE(major, minor) inline
#  define QT_LABSFOLDERLISTMODEL_INLINE_IMPL_SINCE(major, minor) 1
#elif defined(QT_LABSFOLDERLISTMODEL_BUILD_REMOVED_API)
/* inside library, inside removed_api.cpp:
 * keep deprecated API → non-inline decl;
 * remove deprecated API → inline decl;
 * definition is always available */
#  define QT_LABSFOLDERLISTMODEL_INLINE_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
#  define QT_LABSFOLDERLISTMODEL_INLINE_IMPL_SINCE(major, minor) 1
#else
/* inside library, outside removed_api.cpp:
 * keep deprecated API → non-inline decl, no defi;
 * remove deprecated API → inline decl, defi */
#  define QT_LABSFOLDERLISTMODEL_INLINE_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
#  define QT_LABSFOLDERLISTMODEL_INLINE_IMPL_SINCE(major, minor) \
    QT_IF_DEPRECATED_SINCE(major, minor, 1, 0)
#endif

#ifdef QT_LABSFOLDERLISTMODEL_BUILD_REMOVED_API
#  define QT_LABSFOLDERLISTMODEL_REMOVED_SINCE(major, minor) QT_DEPRECATED_SINCE(major, minor)
#else
#  define QT_LABSFOLDERLISTMODEL_REMOVED_SINCE(major, minor) 0
#endif

#endif // QTLABSFOLDERLISTMODELEXPORTS_H
